<?php

namespace Wikibase\Client\Tests\Unit\Usage;

use Exception;
use Wikibase\Client\Usage\EntityUsage;
use Wikibase\Client\Usage\EntityUsageFactory;
use Wikibase\DataModel\Entity\BasicEntityIdParser;
use Wikibase\DataModel\Entity\ItemId;
use Wikibase\DataModel\Entity\PropertyId;

/**
 * @covers \Wikibase\Client\Usage\EntityUsageFactory
 *
 * @group Wikibase
 * @group WikibaseClient
 * @group WikibaseUsageTracking
 *
 * @license GPL-2.0-or-later
 * @author Marius Hoch
 */
class EntityUsageFactoryTest extends \PHPUnit\Framework\TestCase {

	public function newFromIdentityRoundtripProvider() {
		return [
			[ new EntityUsage( new ItemId( 'Q21' ), EntityUsage::ALL_USAGE ) ],
			[ new EntityUsage( new PropertyId( 'P12' ), EntityUsage::LABEL_USAGE, 'blah' ) ],
		];
	}

	/**
	 * @dataProvider newFromIdentityRoundtripProvider
	 * @param EntityUsage $entityUsage
	 */
	public function testNewFromIdentityRoundtrip( EntityUsage $entityUsage ) {
		$factory = new EntityUsageFactory( new BasicEntityIdParser() );

		$this->assertSame(
			$entityUsage->asArray(),
			$factory->newFromIdentity( $entityUsage->getIdentityString() )->asArray()
		);
	}

	public function newFromIdentityInvalidIdentityProvider() {
		return [
			'Invalid format' => [ 'banana' ],
			'Invalid entity id' => [ 'banana#X' ],
			'Invalid aspect' => [ 'Q12#Ü' ],
		];
	}

	/**
	 * @dataProvider newFromIdentityInvalidIdentityProvider
	 *
	 * @param string $identity
	 */
	public function testNewFromIdentityInvalidIdentity( $identity ) {
		$factory = new EntityUsageFactory( new BasicEntityIdParser() );

		$this->expectException( Exception::class );
		$factory->newFromIdentity( $identity );
	}

}
