<?php

namespace Wikibase\Repo\Tests\Store\Sql;

use Title;
use Wikibase\DataModel\Entity\ItemId;
use Wikibase\Lib\Store\EntityIdLookup;
use Wikibase\Lib\Store\EntityNamespaceLookup;
use Wikibase\Repo\Store\Sql\SqlEntityIdPager;
use Wikibase\Repo\Store\Sql\SqlEntityIdPagerFactory;

/**
 * @covers \Wikibase\Repo\Store\Sql\SqlEntityIdPagerFactory
 *
 * @group Wikibase
 * @group WikibaseStore
 *
 * @license GPL-2.0-or-later
 * @author Marius Hoch
 */
class SqlEntityIdPagerFactoryTest extends \PHPUnit\Framework\TestCase {

	public function testNewSqlEntityIdPager() {
		$factory = new SqlEntityIdPagerFactory(
			new EntityNamespaceLookup( [] ),
			$this->getMockEntityIdLookup()
		);
		$pager = $factory->newSqlEntityIdPager();

		$this->assertInstanceOf( SqlEntityIdPager::class, $pager );
	}

	/**
	 * @return EntityIdLookup
	 */
	private function getMockEntityIdLookup() {
		$entityIdLookup = $this->getMockBuilder( EntityIdLookup::class )->getMock();

		$entityIdLookup->expects( $this->any() )
			->method( 'getEntityIdForTitle' )
			->willReturnCallback( function ( Title $title ) {
				return new ItemId( $title->getText() );
			} );

		return $entityIdLookup;
	}

}
